@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Responders
   module Generators
     class InstallGenerator < Rails::Generators::Base
@@ -18,6 +20,14 @@ end
         RUBY
       end
 
+      def update_application
+        inject_into_class "config/application.rb", "Application", <<-RUBY
+    # Use the responders controller from the responders gem
+    config.app_generators.scaffold_controller :responders_controller
+
+        RUBY
+      end
+
       def update_application_controller
         prepend_file "app/controllers/application_controller.rb", %{require "application_responder"\n\n}
         inject_into_class "app/controllers/application_controller.rb", "ApplicationController", <<-RUBY
