@@ -1,5 +1,7 @@
-require 'test_helper'
-require 'support/models'
+# frozen_string_literal: true
+
+require "test_helper"
+require "support/models"
 
 class RespondWithController < ApplicationController
   class CustomerWithJson < Customer
@@ -7,26 +9,26 @@ class RespondWithController < ApplicationController
   end
 
   respond_to :html, :json, :touch
-  respond_to :xml, :except => :using_resource_with_block
-  respond_to :js,  :only => [ :using_resource_with_block, :using_resource, 'using_hash_resource' ]
+  respond_to :xml, except: :using_resource_with_block
+  respond_to :js,  only: [ :using_resource_with_block, :using_resource, "using_hash_resource" ]
 
   def using_resource
     respond_with(resource)
   end
 
   def using_hash_resource
-    respond_with({:result => resource})
+    respond_with(result: resource)
   end
 
   def using_resource_with_block
     respond_with(resource) do |format|
-      format.csv { render :body => "CSV" }
+      format.csv { render body: "CSV", content_type: "text/csv" }
     end
   end
 
   def using_resource_with_overwrite_block
     respond_with(resource) do |format|
-      format.html { render :body => "HTML" }
+      format.html { render html: "HTML" }
     end
   end
 
@@ -39,7 +41,7 @@ class RespondWithController < ApplicationController
   end
 
   def using_resource_with_status_and_location
-    respond_with(resource, :location => "http://test.host/", :status => :created)
+    respond_with(resource, location: "http://test.host/", status: :created)
   end
 
   def using_resource_with_json
@@ -52,22 +54,22 @@ class RespondWithController < ApplicationController
 
   def using_options_with_template
     @customer = resource
-    respond_with(@customer, :status => 123, :location => "http://test.host/")
+    respond_with(@customer, status: 123, location: "http://test.host/")
   end
 
   def using_resource_with_responder
-    responder = proc { |c, r, o| c.render :body => "Resource name is #{r.first.name}" }
-    respond_with(resource, :responder => responder)
+    responder = proc { |c, r, o| c.render body: "Resource name is #{r.first.name}" }
+    respond_with(resource, responder: responder)
   end
 
   def using_resource_with_action
-    respond_with(resource, :action => :foo) do |format|
+    respond_with(resource, action: :foo) do |format|
       format.html { raise ActionView::MissingTemplate.new([], "bar", ["foo"], {}, false) }
     end
   end
 
   def using_resource_with_rendering_options
-    rendering_options = { template: 'addresses/edit', status: :unprocessable_entity }
+    rendering_options = { template: "addresses/edit", status: :unprocessable_entity }
     respond_with(resource, render: rendering_options) do |format|
       format.html { raise ActionView::MissingTemplate.new([], "bar", ["foo"], {}, false) }
     end
@@ -75,20 +77,21 @@ class RespondWithController < ApplicationController
 
   def using_responder_with_respond
     responder = Class.new(ActionController::Responder) do
-      def respond; @controller.render :body => "respond #{format}"; end
+      def respond; @controller.render body: "respond #{format}"; end
     end
-    respond_with(resource, :responder => responder)
+    respond_with(resource, responder: responder)
   end
 
   def respond_with_additional_params
     @params = RespondWithController.params
-    respond_with({:result => resource}, @params)
+    respond_with({ result: resource }, @params)
   end
 
 protected
+
   def self.params
     {
-        :foo => 'bar'
+        foo: "bar"
     }
   end
 
@@ -103,7 +106,7 @@ class InheritedRespondWithController < RespondWithController
 
   def index
     respond_with(resource) do |format|
-      format.json { render :body => "JSON" }
+      format.json { render body: "JSON" }
     end
   end
 end
@@ -133,9 +136,9 @@ class RespondWithControllerTest < ActionController::TestCase
   def setup
     super
     @request.host = "www.example.com"
-    Mime::Type.register_alias('text/html', :iphone)
-    Mime::Type.register_alias('text/html', :touch)
-    Mime::Type.register('text/x-mobile', :mobile)
+    Mime::Type.register_alias("text/html", :iphone)
+    Mime::Type.register_alias("text/html", :touch)
+    Mime::Type.register("text/x-mobile", :mobile)
   end
 
   def teardown
@@ -153,19 +156,19 @@ class RespondWithControllerTest < ActionController::TestCase
   def test_using_resource
     @request.accept = "application/xml"
     get :using_resource
-    assert_equal "application/xml", @response.content_type
+    assert_equal "application/xml", @response.media_type
     assert_equal "<name>david</name>", @response.body
 
     @request.accept = "application/json"
     get :using_resource
-    assert_equal "application/json", @response.content_type
+    assert_equal "application/json", @response.media_type
     assert_equal "{\"name\":\"david\",\"id\":13}", @response.body
   end
 
   def test_using_resource_with_js_simply_tries_to_render_the_template
     @request.accept = "text/javascript"
     get :using_resource
-    assert_equal "text/javascript", @response.content_type
+    assert_equal "text/javascript", @response.media_type
     assert_equal "alert(\"Hi\");", @response.body
   end
 
@@ -179,12 +182,12 @@ class RespondWithControllerTest < ActionController::TestCase
   def test_using_hash_resource
     @request.accept = "application/xml"
     get :using_hash_resource
-    assert_equal "application/xml", @response.content_type
+    assert_equal "application/xml", @response.media_type
     assert_equal "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<hash>\n  <name>david</name>\n</hash>\n", @response.body
 
     @request.accept = "application/json"
     get :using_hash_resource
-    assert_equal "application/json", @response.content_type
+    assert_equal "application/json", @response.media_type
     assert @response.body.include?("result")
     assert @response.body.include?('"name":"david"')
     assert @response.body.include?('"id":13')
@@ -200,23 +203,23 @@ class RespondWithControllerTest < ActionController::TestCase
   def test_using_resource_with_block
     @request.accept = "*/*"
     get :using_resource_with_block
-    assert_equal "text/html", @response.content_type
-    assert_equal 'Hello world!', @response.body
+    assert_equal "text/html", @response.media_type
+    assert_equal "Hello world!", @response.body
 
     @request.accept = "text/csv"
     get :using_resource_with_block
-    assert_equal "text/csv", @response.content_type
+    assert_equal "text/csv", @response.media_type
     assert_equal "CSV", @response.body
 
     @request.accept = "application/xml"
     get :using_resource
-    assert_equal "application/xml", @response.content_type
+    assert_equal "application/xml", @response.media_type
     assert_equal "<name>david</name>", @response.body
   end
 
   def test_using_resource_with_overwrite_block
     get :using_resource_with_overwrite_block
-    assert_equal "text/html", @response.content_type
+    assert_equal "text/html", @response.media_type
     assert_equal "HTML", @response.body
   end
 
@@ -235,7 +238,7 @@ class RespondWithControllerTest < ActionController::TestCase
   def test_using_resource_for_post_with_html_redirects_on_success
     with_test_route_set do
       post :using_resource
-      assert_equal "text/html", @response.content_type
+      assert_equal "text/html", @response.media_type
       assert_equal 302, @response.status
       assert_equal "http://www.example.com/customers/13", @response.location
       assert @response.redirect?
@@ -244,10 +247,10 @@ class RespondWithControllerTest < ActionController::TestCase
 
   def test_using_resource_for_post_with_html_rerender_on_failure
     with_test_route_set do
-      errors = { :name => :invalid }
+      errors = { name: :invalid }
       Customer.any_instance.stubs(:errors).returns(errors)
       post :using_resource
-      assert_equal "text/html", @response.content_type
+      assert_equal "text/html", @response.media_type
       assert_equal 200, @response.status
       assert_equal "New world!\n", @response.body
       assert_nil @response.location
@@ -258,7 +261,7 @@ class RespondWithControllerTest < ActionController::TestCase
     with_test_route_set do
       @request.accept = "application/xml"
       post :using_resource
-      assert_equal "application/xml", @response.content_type
+      assert_equal "application/xml", @response.media_type
       assert_equal 201, @response.status
       assert_equal "<name>david</name>", @response.body
       assert_equal "http://www.example.com/customers/13", @response.location
@@ -268,10 +271,10 @@ class RespondWithControllerTest < ActionController::TestCase
   def test_using_resource_for_post_with_xml_yields_unprocessable_entity_on_failure
     with_test_route_set do
       @request.accept = "application/xml"
-      errors = { :name => :invalid }
+      errors = { name: :invalid }
       Customer.any_instance.stubs(:errors).returns(errors)
       post :using_resource
-      assert_equal "application/xml", @response.content_type
+      assert_equal "application/xml", @response.media_type
       assert_equal 422, @response.status
       assert_equal errors.to_xml, @response.body
       assert_nil @response.location
@@ -281,12 +284,12 @@ class RespondWithControllerTest < ActionController::TestCase
   def test_using_resource_for_post_with_json_yields_unprocessable_entity_on_failure
     with_test_route_set do
       @request.accept = "application/json"
-      errors = { :name => :invalid }
+      errors = { name: :invalid }
       Customer.any_instance.stubs(:errors).returns(errors)
       post :using_resource
-      assert_equal "application/json", @response.content_type
+      assert_equal "application/json", @response.media_type
       assert_equal 422, @response.status
-      errors = {:errors => errors}
+      errors = { errors: errors }
       assert_equal errors.to_json, @response.body
       assert_nil @response.location
     end
@@ -295,7 +298,7 @@ class RespondWithControllerTest < ActionController::TestCase
   def test_using_resource_for_patch_with_html_redirects_on_success
     with_test_route_set do
       patch :using_resource
-      assert_equal "text/html", @response.content_type
+      assert_equal "text/html", @response.media_type
       assert_equal 302, @response.status
       assert_equal "http://www.example.com/customers/13", @response.location
       assert @response.redirect?
@@ -304,10 +307,10 @@ class RespondWithControllerTest < ActionController::TestCase
 
   def test_using_resource_for_patch_with_html_rerender_on_failure
     with_test_route_set do
-      errors = { :name => :invalid }
+      errors = { name: :invalid }
       Customer.any_instance.stubs(:errors).returns(errors)
       patch :using_resource
-      assert_equal "text/html", @response.content_type
+      assert_equal "text/html", @response.media_type
       assert_equal 200, @response.status
       assert_equal "Edit world!\n", @response.body
       assert_nil @response.location
@@ -316,11 +319,11 @@ class RespondWithControllerTest < ActionController::TestCase
 
   def test_using_resource_for_patch_with_html_rerender_on_failure_even_on_method_override
     with_test_route_set do
-      errors = { :name => :invalid }
+      errors = { name: :invalid }
       Customer.any_instance.stubs(:errors).returns(errors)
       @request.env["rack.methodoverride.original_method"] = "POST"
       patch :using_resource
-      assert_equal "text/html", @response.content_type
+      assert_equal "text/html", @response.media_type
       assert_equal 200, @response.status
       assert_equal "Edit world!\n", @response.body
       assert_nil @response.location
@@ -330,7 +333,7 @@ class RespondWithControllerTest < ActionController::TestCase
   def test_using_resource_for_put_with_html_redirects_on_success
     with_test_route_set do
       put :using_resource
-      assert_equal "text/html", @response.content_type
+      assert_equal "text/html", @response.media_type
       assert_equal 302, @response.status
       assert_equal "http://www.example.com/customers/13", @response.location
       assert @response.redirect?
@@ -339,11 +342,11 @@ class RespondWithControllerTest < ActionController::TestCase
 
   def test_using_resource_for_put_with_html_rerender_on_failure
     with_test_route_set do
-      errors = { :name => :invalid }
+      errors = { name: :invalid }
       Customer.any_instance.stubs(:errors).returns(errors)
       put :using_resource
 
-      assert_equal "text/html", @response.content_type
+      assert_equal "text/html", @response.media_type
       assert_equal 200, @response.status
       assert_equal "Edit world!\n", @response.body
       assert_nil @response.location
@@ -352,11 +355,11 @@ class RespondWithControllerTest < ActionController::TestCase
 
   def test_using_resource_for_put_with_html_rerender_on_failure_even_on_method_override
     with_test_route_set do
-      errors = { :name => :invalid }
+      errors = { name: :invalid }
       Customer.any_instance.stubs(:errors).returns(errors)
       @request.env["rack.methodoverride.original_method"] = "POST"
       put :using_resource
-      assert_equal "text/html", @response.content_type
+      assert_equal "text/html", @response.media_type
       assert_equal 200, @response.status
       assert_equal "Edit world!\n", @response.body
       assert_nil @response.location
@@ -379,10 +382,10 @@ class RespondWithControllerTest < ActionController::TestCase
 
   def test_using_resource_for_put_with_xml_yields_unprocessable_entity_on_failure
     @request.accept = "application/xml"
-    errors = { :name => :invalid }
+    errors = { name: :invalid }
     Customer.any_instance.stubs(:errors).returns(errors)
     put :using_resource
-    assert_equal "application/xml", @response.content_type
+    assert_equal "application/xml", @response.media_type
     assert_equal 422, @response.status
     assert_equal errors.to_xml, @response.body
     assert_nil @response.location
@@ -390,12 +393,12 @@ class RespondWithControllerTest < ActionController::TestCase
 
   def test_using_resource_for_put_with_json_yields_unprocessable_entity_on_failure
     @request.accept = "application/json"
-    errors = { :name => :invalid }
+    errors = { name: :invalid }
     Customer.any_instance.stubs(:errors).returns(errors)
     put :using_resource
-    assert_equal "application/json", @response.content_type
+    assert_equal "application/json", @response.media_type
     assert_equal 422, @response.status
-    errors = {:errors => errors}
+    errors = { errors: errors }
     assert_equal errors.to_json, @response.body
     assert_nil @response.location
   end
@@ -404,7 +407,7 @@ class RespondWithControllerTest < ActionController::TestCase
     with_test_route_set do
       Customer.any_instance.stubs(:destroyed?).returns(true)
       delete :using_resource
-      assert_equal "text/html", @response.content_type
+      assert_equal "text/html", @response.media_type
       assert_equal 302, @response.status
       assert_equal "http://www.example.com/customers", @response.location
     end
@@ -428,11 +431,11 @@ class RespondWithControllerTest < ActionController::TestCase
 
   def test_using_resource_for_delete_with_html_redirects_on_failure
     with_test_route_set do
-      errors = { :name => :invalid }
+      errors = { name: :invalid }
       Customer.any_instance.stubs(:errors).returns(errors)
       Customer.any_instance.stubs(:destroyed?).returns(false)
       delete :using_resource
-      assert_equal "text/html", @response.content_type
+      assert_equal "text/html", @response.media_type
       assert_equal 302, @response.status
       assert_equal "http://www.example.com/customers", @response.location
     end
@@ -441,7 +444,7 @@ class RespondWithControllerTest < ActionController::TestCase
   def test_using_resource_with_parent_for_get
     @request.accept = "application/xml"
     get :using_resource_with_parent
-    assert_equal "application/xml", @response.content_type
+    assert_equal "application/xml", @response.media_type
     assert_equal 200, @response.status
     assert_equal "<name>david</name>", @response.body
   end
@@ -451,15 +454,15 @@ class RespondWithControllerTest < ActionController::TestCase
       @request.accept = "application/xml"
 
       post :using_resource_with_parent
-      assert_equal "application/xml", @response.content_type
+      assert_equal "application/xml", @response.media_type
       assert_equal 201, @response.status
       assert_equal "<name>david</name>", @response.body
       assert_equal "http://www.example.com/quiz_stores/11/customers/13", @response.location
 
-      errors = { :name => :invalid }
+      errors = { name: :invalid }
       Customer.any_instance.stubs(:errors).returns(errors)
       post :using_resource
-      assert_equal "application/xml", @response.content_type
+      assert_equal "application/xml", @response.media_type
       assert_equal 422, @response.status
       assert_equal errors.to_xml, @response.body
       assert_nil @response.location
@@ -469,7 +472,7 @@ class RespondWithControllerTest < ActionController::TestCase
   def test_using_resource_with_collection
     @request.accept = "application/xml"
     get :using_resource_with_collection
-    assert_equal "application/xml", @response.content_type
+    assert_equal "application/xml", @response.media_type
     assert_equal 200, @response.status
     assert_match(/<name>david<\/name>/, @response.body)
     assert_match(/<name>jamis<\/name>/, @response.body)
@@ -477,16 +480,16 @@ class RespondWithControllerTest < ActionController::TestCase
 
   def test_using_resource_with_action
     @controller.instance_eval do
-      def render(params={})
+      def render(params = {})
         self.response_body = "#{params[:action]} - #{formats}"
       end
     end
 
-    errors = { :name => :invalid }
+    errors = { name: :invalid }
     Customer.any_instance.stubs(:errors).returns(errors)
 
     post :using_resource_with_action
-    assert_equal "foo - #{[:html].to_s}", @controller.response.body
+    assert_equal "foo - #{[:html]}", @controller.response.body
   end
 
   def test_using_resource_with_rendering_options
@@ -495,7 +498,7 @@ class RespondWithControllerTest < ActionController::TestCase
     post :using_resource_with_rendering_options
 
     assert_response :unprocessable_entity
-    assert_equal 'edit.html.erb', @controller.response.body
+    assert_equal "edit.html.erb", @controller.response.body
   end
 
   def test_respond_as_responder_entry_point
@@ -520,7 +523,7 @@ class RespondWithControllerTest < ActionController::TestCase
     @controller = InheritedRespondWithController.new
     @request.accept = "*/*"
     get :index
-    assert_equal "application/xml", @response.content_type
+    assert_equal "application/xml", @response.media_type
     assert_equal "<name>david</name>", @response.body
   end
 
@@ -550,7 +553,7 @@ class RespondWithControllerTest < ActionController::TestCase
   end
 
   def test_using_resource_with_status_and_location_with_invalid_resource
-    errors = { :name => :invalid }
+    errors = { name: :invalid }
     Customer.any_instance.stubs(:errors).returns(errors)
 
     @request.accept = "text/xml"
@@ -558,16 +561,16 @@ class RespondWithControllerTest < ActionController::TestCase
     post :using_resource_with_status_and_location
     assert_equal errors.to_xml, @response.body
     assert_equal 422, @response.status
-    assert_equal nil, @response.location
+    assert_nil @response.location
 
     put :using_resource_with_status_and_location
     assert_equal errors.to_xml, @response.body
     assert_equal 422, @response.status
-    assert_equal nil, @response.location
+    assert_nil @response.location
   end
 
   def test_using_invalid_resource_with_template
-    errors = { :name => :invalid }
+    errors = { name: :invalid }
     Customer.any_instance.stubs(:errors).returns(errors)
 
     @request.accept = "text/xml"
@@ -575,12 +578,12 @@ class RespondWithControllerTest < ActionController::TestCase
     post :using_invalid_resource_with_template
     assert_equal errors.to_xml, @response.body
     assert_equal 422, @response.status
-    assert_equal nil, @response.location
+    assert_nil @response.location
 
     put :using_invalid_resource_with_template
     assert_equal errors.to_xml, @response.body
     assert_equal 422, @response.status
-    assert_equal nil, @response.location
+    assert_nil @response.location
   end
 
   def test_using_options_with_template
@@ -603,7 +606,7 @@ class RespondWithControllerTest < ActionController::TestCase
   end
 
   def test_using_resource_with_set_responder
-    RespondWithController.responder = proc { |c, r, o| c.render :body => "Resource name is #{r.first.name}" }
+    RespondWithController.responder = proc { |c, r, o| c.render body: "Resource name is #{r.first.name}" }
     get :using_resource
     assert_equal "Resource name is david", @response.body
   ensure
@@ -613,7 +616,7 @@ class RespondWithControllerTest < ActionController::TestCase
   def test_raises_missing_renderer_if_an_api_behavior_with_no_renderer
     @controller = CsvRespondWithController.new
     assert_raise ActionController::MissingRenderer do
-      get :index, format: 'csv'
+      get :index, format: "csv"
     end
   end
 
@@ -626,20 +629,21 @@ class RespondWithControllerTest < ActionController::TestCase
   end
 
   private
-    def with_test_route_set
-      with_routing do |set|
-        set.draw do
+
+  def with_test_route_set
+    with_routing do |set|
+      set.draw do
+        resources :customers
+        resources :quiz_stores do
           resources :customers
-          resources :quiz_stores do
-            resources :customers
-          end
-          ActiveSupport::Deprecation.silence do
-            get ':controller/:action'
-          end
         end
-        yield
+        ActiveSupport::Deprecation.silence do
+          get ":controller/:action"
+        end
       end
+      yield
     end
+  end
 end
 
 class LocationsController < ApplicationController
@@ -652,11 +656,11 @@ class LocationsController < ApplicationController
   end
 
   def create
-    respond_with @resource, location: -> { 'given_location' }
+    respond_with @resource, location: -> { "given_location" }
   end
 
   def update
-    respond_with @resource, location: 'given_location'
+    respond_with @resource, location: "given_location"
   end
 
   def set_resource
@@ -670,16 +674,16 @@ class LocationResponderTest < ActionController::TestCase
 
   def test_redirects_to_block_location_on_success
     post :create
-    assert_redirected_to 'given_location'
+    assert_redirected_to "given_location"
   end
 
   def test_renders_page_on_fail
     post :create, params: { fail: true }
-    assert @response.body.include?('new.html.erb')
+    assert @response.body.include?("new.html.erb")
   end
 
   def test_redirects_to_plain_string
     post :update
-    assert_redirected_to 'given_location'
+    assert_redirected_to "given_location"
   end
 end
